#
# spec file for package plotutils
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plotutils
Version:        2.6
Release:        31.1
Summary:        GNU Plotting Utilities
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Productivity/Graphics/Visualization/Graph
URL:            https://www.gnu.org/software/plotutils/plotutils.html
Source:         https://ftp.gnu.org/gnu/plotutils/%{name}-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/plotutils/plotutils-2.6.tar.gz.sig
Source2:        plotutils.keyring
Patch0:         plotutils-man.patch
Patch1:         plotutils-uninitialized.patch
Patch2:         plotutils-dasharray-format.patch
Patch3:         plotutils-autoreconf.patch
# libpng15.patch sent 2012-08-30 at rsm@math.arizona.edu
Patch4:         plotutils-libpng15.patch
# PATCH-FIX-UPSTREAM Arithmetic overflow in Hershey pointing hands glyphs
Patch5:         plotutils-hershey_glyphs.patch
# PATCH-FIX-UPSTREAM --no-of-intervals arugment is documented wrongly originall
Patch6:         plotutils-man-spline.patch
# PATCH-FIX-UPSTREAM repairs postscript output
Patch7:         plotutils-postscript.patch
# build with gcc15
Patch8:         plotutils-gcc15.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  fontpackages-devel
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xt)
%{?reconfigure_fonts_prereq: %reconfigure_fonts_prereq}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The GNU plotting utilities consist of seven command line programs: the
graphics programs `graph', `plot', `tek2plot', and `plotfont', and the
mathematical programs `spline', `ode', and `double'.  GNU `libplot' is
distributed with these programs; it is the library on which the
graphics programs are based. `Libplot' is a function library for
device-independent two-dimensional vector graphics, including vector
graphics animations under the X Window System.

%package devel
Summary:        GNU Plotting Utilities
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       bison
Requires:       flex
Requires:       fontpackages-devel
Requires:       gcc-c++
Requires:       libplot2 = %{version}
Requires:       libplotter2 = %{version}
Requires:       libpng-devel
Requires:       libstdc++-devel
Requires:       libtool
Requires:       libxmi0 = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xaw7)
Requires:       pkgconfig(xext)
Requires:       pkgconfig(xt)

%description devel
The GNU plotting utilities consist of seven command line programs: the
graphics programs `graph', `plot', `tek2plot', and `plotfont', and the
mathematical programs `spline', `ode', and `double'.  GNU `libplot' is
distributed with these programs; it is the library on which the
graphics programs are based. `Libplot' is a function library for
device-independent two-dimensional vector graphics, including vector
graphics animations under the X Window System.

%package doc
Summary:        GNU Plotting Utilities
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       %{name}:%{_docdir}/%{name}/README
BuildArch:      noarch

%description doc
The GNU plotting utilities consist of seven command line programs: the
graphics programs `graph', `plot', `tek2plot', and `plotfont', and the
mathematical programs `spline', `ode', and `double'.  GNU `libplot' is
distributed with these programs; it is the library on which the
graphics programs are based. `Libplot' is a function library for
device-independent two-dimensional vector graphics, including vector
graphics animations under the X Window System.

%package -n libplot2
Summary:        GNU Plotting Utilities
Group:          System/Libraries

%description -n libplot2
The GNU plotting utilities consist of seven command line programs: the
graphics programs `graph', `plot', `tek2plot', and `plotfont', and the
mathematical programs `spline', `ode', and `double'.  GNU `libplot' is
distributed with these programs; it is the library on which the
graphics programs are based. `Libplot' is a function library for
device-independent two-dimensional vector graphics, including vector
graphics animations under the X Window System.

%package -n libplotter2
Summary:        GNU Plotting Utilities
Group:          System/Libraries

%description -n libplotter2
The GNU plotting utilities consist of seven command line programs: the
graphics programs `graph', `plot', `tek2plot', and `plotfont', and the
mathematical programs `spline', `ode', and `double'.  GNU `libplot' is
distributed with these programs; it is the library on which the
graphics programs are based. `Libplot' is a function library for
device-independent two-dimensional vector graphics, including vector
graphics animations under the X Window System.

%package -n libxmi0
Summary:        GNU Plotting Utilities
Group:          System/Libraries

%description -n libxmi0
The GNU plotting utilities consist of seven command line programs: the
graphics programs `graph', `plot', `tek2plot', and `plotfont', and the
mathematical programs `spline', `ode', and `double'.  GNU `libplot' is
distributed with these programs; it is the library on which the
graphics programs are based. `Libplot' is a function library for
device-independent two-dimensional vector graphics, including vector
graphics animations under the X Window System.

%prep
%{?gpg_verify: %gpg_verify %{S:1}}
%setup -q
%patch -P 0 -p0
%patch -P 1 -p0
%patch -P 2 -p0
%patch -P 3 -p0 -b .p3
%patch -P 4 -p1
%patch -P 5 -p0
%patch -P 6 -p0
%patch -P 7 -p0
%patch -P 8 -p1
# Avoid update lex and bison code as otherwise we may see broken code (bnc#829479)
# that is do *not* remove any lex\yacc code
grep -rslE '(made by GNU Bison|A Bison parser, made from|"lex.yy.c")' . | xargs -r touch

%build
export CXXFLAGS="%optflags -fvisibility-inlines-hidden"
autoreconf -f -i
%configure --with-pic\
	--disable-static\
	--enable-libplotter\
	--enable-libxmi
%make_build

%install
%make_install\
	libplotdatadir=%{_docdir}/%{name}/libplot\
	odedatadir=%{_docdir}/%{name}/ode\
	tek2plotdatadir=%{_docdir}/%{name}/tek2plot\
	pic2plotdatadir=%{_docdir}/%{name}/pic2plot
#
install -m 0644\
	AUTHORS COMPAT INSTALL.fonts KNOWN_BUGS PROBLEMS README THANKS\
	TODO %{buildroot}%{_defaultdocdir}/%{name}
#
install -d %{buildroot}%{_miscfontsdir}
install -m 0644 fonts/pcf/*.pcf %{buildroot}%{_miscfontsdir}
gzip -n -9 %{buildroot}%{_miscfontsdir}/*.pcf
#
install -m 0644 manpage.1 %{buildroot}%{_mandir}/man1/plotutils.1
ln -s plotutils.1.gz %{buildroot}%{_mandir}/man1/double.1.gz
ln -s plotutils.1.gz %{buildroot}%{_mandir}/man1/graph.1.gz
ln -s plotutils.1.gz %{buildroot}%{_mandir}/man1/pic2plot.1.gz
rm -f %{buildroot}%{_libdir}/*.la

%post
%reconfigure_fonts_post

%postun
%reconfigure_fonts_postun

%posttrans
%reconfigure_fonts_posttrans

%post -n libplot2 -p /sbin/ldconfig

%postun -n libplot2 -p /sbin/ldconfig

%post -n libplotter2 -p /sbin/ldconfig

%postun -n libplotter2 -p /sbin/ldconfig

%post -n libxmi0 -p /sbin/ldconfig

%postun -n libxmi0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%license COPYING
%{_bindir}/*
%doc %{_infodir}/plotutils*.info*
%doc %{_mandir}/man?/*.*
%{_miscfontsdir}

%files doc
%defattr(-,root,root)
%doc %{_docdir}/%{name}

%files devel
%defattr(-,root,root)
%{_libdir}/lib*.so
%{_includedir}/*.h
%doc %{_infodir}/libxmi*.info*

%files -n libplot2
%defattr(-,root,root)
%{_libdir}/libplot.so.*

%files -n libplotter2
%defattr(-,root,root)
%{_libdir}/libplotter.so.*

%files -n libxmi0
%defattr(-,root,root)
%{_libdir}/libxmi.so.*

%changelog
* Tue Mar 11 2025 pgajdos@suse.com
- added patches
  fix build with gcc15
  + plotutils-gcc15.patch
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep 21 2022 Dr. Werner Fink <werner@suse.de>
- Go from http to https
- Split doc package off
- Some modern rpm macros
- Skip obsolete rpm macros
- Extend patch plotutils-autoreconf.patch
  * More changes to autobuild toolset files
* Mon Apr 16 2018 astieger@suse.com
- remove dependendy on gpg-offline, this is now part of the
  standard source services
- Use %%license (boo#1082318)
* Sat Apr 29 2017 bwiedemann@suse.com
- Call gzip -n to make build fully reproducible
* Mon Oct  6 2014 crrodriguez@opensuse.org
- Restrict xorg library requires to the mininum needed.
- BUild C++ bits with -fvisibility-inlines-hidden.
* Mon Jul 15 2013 werner@suse.de
- Do not remove lex/yacc code as current bison generate broken
  code (fix for bnc#829479, depends on bnc#829497)
- Add plotutils-hershey_glyphs.patch to avoid arithmetic overflow
  in Hershey pointing hands glyphs
- Add plotutils-man-spline.patch as there is no --number-of-intervals
  but --no-of-intervals option
- Add plotutils-postscript.patch to avoid broken postscript due not
  initialized variable
* Mon Apr 15 2013 idonmez@suse.com
- Cleanup spec file
- Add Source URL, see https://en.opensuse.org/SourceUrls
- Add GPG checking
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Wed Aug 29 2012 pgajdos@suse.com
- build also with libpng15
  * libpng15.patch
* Mon Aug  6 2012 pgajdos@suse.com
- prepare spec file for dropping SuSEconfig.fonts (openFATE#313536)
* Wed Nov 16 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Nov 26 2009 werner@suse.de
- Update to version 2.6 as this fix a copyright problem of mixing
  GPL and non-commercial code (bnc#465378)
* Tue Jan 20 2009 crrodriguez@suse.de
- fix -devel package dependencies (and build of package enblend-enfuse)
- remove "la" files
* Thu Jan  8 2009 sbrabec@suse.cz
- Updated to version 2.5.1:
  * Minor SVG output format fixes for compatability with SVG 1.1.
  * Error formatting changes.
  * New license: GPL version 3.
- Install upstream man pages.
- Split package and patch according to packaging rules.
- Simplified spec file.
- Disabled static libraries.
- Update lex & bison files.
- Removed obsolete version checks.
* Thu Jan  8 2009 werner@suse.de
- Add a fix in libplot/s_path.c to get valid SVG files (bnc#464381)
* Thu Aug 10 2006 mfabian@suse.de
- move fonts to /usr/share/fonts/misc (because of X11R7).
* Mon May 22 2006 werner@suse.de
- Update to plotutils 2.5
  libplot:
  * support for rotated and sheared (i.e., "anamorphically
    transformed") X Window System fonts has been completely rewritten.
  * URW versions of the standard 35 Adobe fonts (Helvetica,
    Times-Roman etc.) are now checked for under their own names on any
    X Window System display, as well as under the Adobe names.
  * SVG output is now conformant SVG 1.1
  * vertical positioning of text strings by the SVG driver improved
  * the ROTATION parameter can now take values other than 0, 90, 180, and 270.
  * modifiers fixed, such as appended "xsize=6in", "yoffset=8cm"
  * problems with PS output triggering an error in some versions of
    ghostscript now fixed
  * most external symbols not meant to be publicly accessible now have
    names beginning with the prefix "_pl_", to reduce the possibility
    of namespace collisions.  This will be completed in a later release.
  graph:
  * plotting of rotated y-axis labels by the `-Y' option, when `-T X' is
    specified
  * new short `-Q' option, equivalent to `--toggle-rotate-y-axis-label'.
  graph,plot,tek2plot,plotfont,pic2plot:
  * `--display-type' long option, the name of which confused some users,
    has been changed to `--output-format'.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec  3 2004 mfabian@suse.de
- use new macro "%%run_suseconfig_fonts".
* Wed Dec  1 2004 werner@suse.de
- Do not be fooled by missing SuSEconfig module on non X11 systems
* Fri Mar 19 2004 mfabian@suse.de
- use %%suseconfig_fonts_prereq
- run SuSEconfig.fonts and SuSEconfig.pango in %%post and %%postun
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Feb 28 2003 werner@suse.de
- Fix bug #23452: use intall-info for info file
* Fri Nov 22 2002 olh@suse.de
- obsoletes/provides plotutil (#21848)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Jun 18 2002 meissner@suse.de
- rerun auto* tools.
* Fri May  3 2002 werner@suse.de
- Set correct X11 library path
- Automagic update of config.guess and config.sub
* Mon Dec 17 2001 werner@suse.de
- Update to 2.4.1
- Use BuildRoot
- Rename package from plotutil to plotutils
* Tue Jun 26 2001 schwab@suse.de
- Fix for gcc 3.0.
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Wed May 31 2000 werner@suse.de
- Use %%{_defaultdocdir}
* Wed Mar  8 2000 bs@suse.de
- no ldconfig in %%post please.
* Fri Feb 11 2000 werner@suse.de
- Fix call of ldconfig, only if called in real root file system
* Thu Jan 20 2000 ro@suse.de
- update to 2.3 to make it build
- info,man: use macros to move to /usr/share
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Apr  5 1999 bs@suse.de
- fixed date strings in .changes.
* Fri Mar 26 1999 werner@suse.de
- Update to version 2.2
* Wed Mar  3 1999 werner@suse.de
- New package, version 2.1.6
